@@ -16,14 +16,21 @@
 #' @param error_bar_range width of the confidence or prediction interval
 #' (default = 0.95 for 95 percent confidence or prediction interval).
 #' This argument will not apply when \code{error_bar = "se"}
-#' @param lines_connecting_means logical. Should lines connecting means
-#' within each group be drawn? (default = TRUE)
-#' @param line_size thickness of the lines connecting group means,
-#' (default = 1)
-#' @param dot_size size of the dots indicating group means (default = 3)
 #' @param error_bar_tip_width graphically, width of the segments
 #' at the end of error bars (default = 0.13)
 #' @param error_bar_thickness thickness of the error bars (default = 1)
+#' @param error_bar_caption should a caption be included to indicate
+#' the width of the error bars? (default = TRUE).
+#' @param lines_connecting_means logical. Should lines connecting means
+#' within each group be drawn? (default = TRUE)
+#' @param line_types types of the lines connecting means (default = NULL)
+#' If the second IV has two levels, then by default,
+#' \code{line_types = c("solid", "dashed")}
+#' @param line_thickness thickness of the lines connecting group means
+#' (default = 1)
+#' @param line_size Deprecated. Use the 'linewidth' argument instead.
+#' (default = 1)
+#' @param dot_size size of the dots indicating group means (default = 3)
 #' @param position_dodge by how much should the group means and error bars
 #' be horizontally offset from each other so as not to overlap?
 #' (default = 0.13)
@@ -55,11 +62,14 @@ plot_group_means <- function(
   na.rm = TRUE,
   error_bar = "ci",
   error_bar_range = 0.95,
-  lines_connecting_means = TRUE,
-  line_size = 1,
-  dot_size = 3,
   error_bar_tip_width = 0.13,
   error_bar_thickness = 1,
+  error_bar_caption = TRUE,
+  lines_connecting_means = TRUE,
+  line_types = NULL,
+  line_thickness = 1,
+  line_size = NULL,
+  dot_size = 3,
   position_dodge = 0.13,
   legend_position = "right",
   y_axis_title_vjust = 0.85) {
@@ -74,6 +84,14 @@ plot_group_means <- function(
       "'kim::install_all_dependencies()'"))
     return()
   }
+  # check arguments
+  if (!is.null(line_size)) {
+    warning(paste0(
+      "The use of the 'line_size' argument was deprecated",
+      "\ndue to a change in ggplot2 3.4.0.\n",
+      "Going forward, please use the 'line_thickness' argument instead."))
+    line_thickness <- line_size
+  }
   # convert to data table
   dt1 <- data.table::setDT(
     data.table::copy(data))[, c(dv_name, iv_name), with = FALSE]
@@ -111,15 +129,28 @@ plot_group_means <- function(
       y = mean,
       x = get(iv_name[1]),
       color = get(iv_name[2]),
-      group = get(iv_name[2])
+      group = get(iv_name[2]),
+      linetype = get(iv_name[2])
     ))
+    # number of levels in the second IV
+    num_of_levels_in_iv2 <- length(unique(dt2[, get(iv_name[2])]))
+  }
+  # set defaults if there are two levels in IV 2
+  if (num_of_levels_in_iv2 == 2) {
+    line_types = c("solid", "dashed")
+    line_colors = c("red", "blue")
   }
   # The errorbars will overlap,
   # so use position_dodge to move them horizontally
   pd <- ggplot2::position_dodge(width = position_dodge)
   # points and lines
   if (lines_connecting_means == TRUE) {
-    g1 <- g1 + ggplot2::geom_line(size = line_size, position = pd)
+    g1 <- g1 + ggplot2::geom_line(
+      linewidth = line_thickness, position = pd)
+    if (!is.null(line_types)) {
+      g1 <- g1 + ggplot2::scale_linetype_manual(
+        values = line_types)
+    }
   }
   g1 <- g1 + ggplot2::geom_point(size = dot_size, position = pd)
   if (length(iv_name) == 2) {
@@ -161,11 +192,21 @@ plot_group_means <- function(
   }
   g1 <- g1 + ggplot2::xlab(iv_name[1])
   g1 <- g1 + ggplot2::ylab(dv_name)
-  g1 <- g1 + ggplot2::labs(caption = paste0(
-    "\nError bars indicate ", error_bar_desc_text, " around the mean."))
+  g1 <- g1 + ggplot2::labs(
+    color = iv_name[2],
+    linetype = iv_name[2])
+  if (error_bar_caption == TRUE) {
+    g1 <- g1 + ggplot2::labs(
+      caption = paste0(
+        "\nError bars indicate ", error_bar_desc_text,
+        " around the mean."))
+  }
   # plot theme
   g1 <- g1 + kim::theme_kim(
     y_axis_title_vjust = y_axis_title_vjust,
     legend_position = legend_position)
+  g1 <- g1 + ggplot2::theme(
+    legend.spacing.y = ggplot2::unit(1, "cm"),
+    legend.key.size = ggplot2::unit(3, "lines"))
   return(g1)
 }
