@@ -1,7 +1,7 @@
-#' t test, pairwise
+#' t-tests, pairwise
 #'
 #' Conducts a t-test for every possible pairwise comparison
-#' with Bonferroni correction
+#' with Holm or Bonferroni correction
 #'
 #' @param data a data object (a data frame or a data.table)
 #' @param iv_name name of the independent variable
@@ -11,7 +11,13 @@
 #' included in the output data.table.
 #' @param cohen_d_w_ci if \code{cohen_d_w_ci = TRUE},
 #' Cohen's d with 95% CI will be included in the output data.table.
-#' @param bonferroni if \code{bonferroni = TRUE}, Bonferroni tests will be
+#' @param adjust_p the name of the method to use to adjust p-values.
+#' If \code{adjust_p = "holm"}, the Holm method will be used;
+#' if \code{adjust_p = "bonferroni"}, the Bonferroni method will be used.
+#' By default, \code{adjust_p = "holm"}
+#' @param bonferroni The use of this argument is deprecated.
+#' Use the 'adjust_p' argument instead.
+#' If \code{bonferroni = TRUE}, Bonferroni tests will be
 #' conducted for t-tests or Mann-Whitney tests.
 #' @param mann_whitney if \code{TRUE}, Mann-Whitney test results will be
 #' included in the output data.table. If \code{FALSE}, Mann-Whitney
@@ -24,6 +30,10 @@
 #' included in the output data.table.
 #' @param round_p number of decimal places to which to round
 #' p-values (default = 3)
+#' @param anova Should a one-way ANOVA be conducted and reported?
+#' (default = TRUE)
+#' @param round_f number of decimal places to which to round
+#' the f statistic (default = 2)
 #' @return the output will be a data.table showing results of all
 #' pairwise comparisons between levels of the independent variable.
 #' @examples
@@ -43,12 +53,15 @@ t_test_pairwise <- function(
   sigfigs = 3,
   cohen_d = TRUE,
   cohen_d_w_ci = TRUE,
-  bonferroni = TRUE,
+  adjust_p = "holm",
+  bonferroni = NULL,
   mann_whitney = TRUE,
   t_test_stats = FALSE,
   t_test_df_decimals = 1,
   sd = FALSE,
-  round_p = 3) {
+  round_p = 3,
+  anova = TRUE,
+  round_f = 2) {
   # bind the vars locally to the function
   iv <- dv <- group_1 <- group_2 <- NULL
   # check number of iv_name and dv_name
@@ -64,6 +77,25 @@ t_test_pairwise <- function(
   # convert iv to factor
   dt01[, iv := factor(iv)]
   dt01 <- stats::na.omit(dt01)
+  # conduct and report a one way anova
+  if (anova == TRUE) {
+    anova_results <- stats::aov(dv ~ iv, data = dt01)
+    # alternatively called: Degree of Freedom for Groups,
+    # df groups, df between
+    anova_df_groups <- summary(anova_results)[[1]]["iv", "Df"]
+    # alternatively called: Degree of Freedom for Error,
+    # df error, df within, df residual
+    anova_df_error <- summary(anova_results)[[1]]["Residuals", "Df"]
+    anova_f <- summary(anova_results)[[1]]["iv", "F value"]
+    anova_p <- summary(anova_results)[[1]]["iv", "Pr(>F)"]
+    results <- paste0(
+      "One-way ANOVA revealed that '", dv_name,
+      "'\nvaried significantly as a function of '", iv_name,
+      ",'\nF(", anova_df_groups, ", ", anova_df_error, ") = ",
+      round(anova_f, round_f), ", ",
+      kim::pretty_round_p_value(anova_p, include_p_equals = TRUE), ".\n")
+    message(results)
+  }
   # pairs
   group <- sort(unique(dt01$iv))
   dt02 <- data.table::data.table(t(utils::combn(group, 2)))
@@ -176,26 +208,47 @@ t_test_pairwise <- function(
   if (mann_whitney == TRUE) {
     mann_whitney_p_value <- vapply(seq_len(nrow(dt02)), function(i) {
       stats::wilcox.test(
-        dv ~ iv, dt01[iv %in% dt02[i, ]],
-        paired = FALSE)[["p.value"]]},
+        dv ~ iv, dt01[iv %in% dt02[i, ]])[["p.value"]]},
       FUN.VALUE = numeric(1L))
     output[, "mann_whitney_p_value" := kim::pretty_round_p_value(
       p_value_vector = mann_whitney_p_value,
       round_digits_after_decimal = round_p)][]
   }
-  # if bonferroni
-  if (bonferroni == TRUE) {
-    # bonferroni sig for t test
-    bonferroni_signif_for_t_test <- ifelse(
-      t_test_p_value < .05 / nrow(dt02), "Yes", "No")
-    output[, "bonferroni_signif_for_t_test" :=
-             bonferroni_signif_for_t_test][]
-    # bonferroni sig for mann whitney
-    if (mann_whitney == TRUE) {
-      bonferroni_signif_for_mann_whitney <- ifelse(
-        mann_whitney_p_value < .05 / nrow(dt02), "Yes", "No")
-      output[, "bonferroni_signif_for_mann_whitney" :=
-               bonferroni_signif_for_mann_whitney][]
+  # adjust p values
+  if (!is.null(bonferroni)) {
+    if (bonferroni == TRUE) {
+      adjust_p <- "bonferroni"
+      warning(paste0(
+        "The use of the 'bonferroni' argument is deprecated.\n",
+        "Use the 'adjust_p' argument instead ",
+        '(e.g., adjust_p = "bonferroni").'))
+    }
+  }
+  # adjust p values with bonferroni
+  if (length(t_test_p_value) > 1) {
+    if (adjust_p == "holm") {
+      holm_adjusted_p_for_t_tests <- kim::pretty_round_p_value(
+        stats::p.adjust(p = t_test_p_value, method = "holm"))
+      output <- data.table::data.table(output, holm_adjusted_p_for_t_tests)
+      if (mann_whitney == TRUE) {
+        holm_adjusted_p_for_mann_whitney <- kim::pretty_round_p_value(
+          stats::p.adjust(
+            p = mann_whitney_p_value, method = "holm"))
+        output <- data.table::data.table(
+          output, holm_adjusted_p_for_mann_whitney)
+      }
+    } else if (adjust_p == "bonferroni") {
+      bonferroni_adjusted_p_for_t_tests <- kim::pretty_round_p_value(
+        stats::p.adjust(p = t_test_p_value, method = "bonferroni"))
+      output <- data.table::data.table(
+        output, bonferroni_adjusted_p_for_t_tests)
+      if (mann_whitney == TRUE) {
+        bonferroni_adjusted_p_for_mann_whitney <-
+          kim::pretty_round_p_value(stats::p.adjust(
+            p = mann_whitney_p_value, method = "bonferroni"))
+        output <- data.table::data.table(
+          output, bonferroni_adjusted_p_for_mann_whitney)
+      }
     }
   }
   return(output)
